@@ -4,7 +4,7 @@ pub struct Cash {
 }
 
 impl Cash {
-    pub fn new(currency: &str, amount: i64) -> Self {
+    pub fn create(currency: &str, amount: i64) -> Self {
         Self {
             currency: String::from(currency),
             amount: amount,
